@@ -149,8 +149,8 @@ def plot_field_map(field_var, lat, lon, levels=50, add_cyclic_point=True,
                    land_zorder=None, ocean_zorder=None, signif_values=None, signif_range=[0.05, 9999], hatch='..',
                    clim=None, cmap=None, cmap_under=None, cmap_over=None, extend=None, mode='latlon', add_gridlines=False,
                    make_cbar=True, cbar_labels=None, cbar_pad=0.05, cbar_orientation='vertical', cbar_aspect=10,
-                   cbar_fraction=0.15, cbar_shrink=0.5, cbar_title=None, font_scale=1.5, plot_type=None,
-                   fig=None, ax=None):
+                   cbar_fraction=0.15, cbar_shrink=0.5, cbar_title=None, cbar_title_x=0.5, cbar_title_y=1.05,
+                   font_scale=1.5, plot_type=None, fig=None, ax=None):
 
     if plot_type == 'corr':
         clim = [-1, 1] if clim is None else clim
@@ -272,7 +272,7 @@ def plot_field_map(field_var, lat, lon, levels=50, add_cyclic_point=True,
             cbar.set_ticks(cbar_labels)
 
         if cbar_title:
-            cbar.ax.set_title(cbar_title)
+            cbar.ax.set_title(cbar_title, x=cbar_title_x, y=cbar_title_y)
 
     if site_lats is not None and site_lons is not None:
         if type(site_lats) is not dict:
@@ -493,7 +493,7 @@ def in_notebook():
     return True
 
 
-def showfig(fig, close=False):
+def showfig(fig, close=True):
     '''Show the figure
 
     Parameters
@@ -504,11 +504,6 @@ def showfig(fig, close=False):
     close : bool
         if True, close the figure automatically
 
-    See Also
-    --------
-    pyleoclim.utils.plotting.savefig : saves a figure to a specific path
-    pyleoclim.utils.plotting.in_notebook: Functions to sense a notebook environment
-
     '''
     if in_notebook:
         try:
@@ -1081,4 +1076,11 @@ def plot_volc_cdf(year_volc, anom_volc, anom_nonvolc, anom_nonvolc_draws, value_
         if 'fig' in locals():
             return fig, ax
         else:
-            return ax
\ No newline at end of file
+            return ax
+
+def make_lb(name, unit):
+    if unit is not None:
+        lb = f'{name} [{unit}]'
+    else:
+        lb = f'{name}'
+    return lb
\ No newline at end of file
